KachePersistenceOwnership enum
Determines whether a client may close its persistence backend.
Values
- borrowed → const KachePersistenceOwnership
-
The backend is managed externally and must not be closed by the client.
- owned → const KachePersistenceOwnership
-
The client owns the backend and closes it with the client lifecycle.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
KachePersistenceOwnership> - A constant List of the values in this enum, in order of their declaration.